// Copyright 2022 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// GENERATED FROM THE API DEFINITION IN
//   extensions/common/api/virtual_keyboard_private.json
// by tools/json_schema_compiler.
// DO NOT EDIT.

#include "extensions/common/api/virtual_keyboard_private.h"

#include <memory>
#include <ostream>
#include <string>
#include <utility>
#include <vector>

#include "base/check.h"
#include "base/check_op.h"
#include "base/notreached.h"
#include "base/strings/string_number_conversions.h"
#include "base/strings/utf_string_conversions.h"
#include "base/values.h"
#include "tools/json_schema_compiler/util.h"

using base::UTF8ToUTF16;

namespace extensions {
namespace api {
namespace virtual_keyboard_private {
//
// Types
//

const char* ToString(VirtualKeyboardEventType enum_param) {
  switch (enum_param) {
    case VIRTUAL_KEYBOARD_EVENT_TYPE_KEYUP:
      return "keyup";
    case VIRTUAL_KEYBOARD_EVENT_TYPE_KEYDOWN:
      return "keydown";
    case VIRTUAL_KEYBOARD_EVENT_TYPE_NONE:
      return "";
  }
  NOTREACHED();
  return "";
}

VirtualKeyboardEventType ParseVirtualKeyboardEventType(const std::string& enum_string) {
  if (enum_string == "keyup")
    return VIRTUAL_KEYBOARD_EVENT_TYPE_KEYUP;
  if (enum_string == "keydown")
    return VIRTUAL_KEYBOARD_EVENT_TYPE_KEYDOWN;
  return VIRTUAL_KEYBOARD_EVENT_TYPE_NONE;
}


VirtualKeyboardEvent::VirtualKeyboardEvent()
: type(VIRTUAL_KEYBOARD_EVENT_TYPE_NONE),
char_value(0),
key_code(0) {}

VirtualKeyboardEvent::~VirtualKeyboardEvent() = default;
VirtualKeyboardEvent::VirtualKeyboardEvent(VirtualKeyboardEvent&& rhs) = default;
VirtualKeyboardEvent& VirtualKeyboardEvent::operator=(VirtualKeyboardEvent&& rhs) = default;
// static
bool VirtualKeyboardEvent::Populate(
    const base::Value& value, VirtualKeyboardEvent* out) {
  if (!value.is_dict()) {
    return false;
  }
  const auto* dict = static_cast<const base::DictionaryValue*>(&value);
  const base::Value* type_value = dict->FindKey("type");
  if (!type_value) {
    return false;
  }
  {
    const std::string* virtual_keyboard_event_type_as_string = (*type_value).GetIfString();
    if (!virtual_keyboard_event_type_as_string) {
      return false;
    }
    out->type = ParseVirtualKeyboardEventType(*virtual_keyboard_event_type_as_string);
    if (out->type == VIRTUAL_KEYBOARD_EVENT_TYPE_NONE) {
      return false;
    }
  }

  const base::Value* char_value_value = dict->FindKey("charValue");
  if (!char_value_value) {
    return false;
  }
  {
    auto temp = (*char_value_value).GetIfInt();
    if (!temp.has_value()) {
      return false;
    }
    out->char_value = temp.value();
  }

  const base::Value* key_code_value = dict->FindKey("keyCode");
  if (!key_code_value) {
    return false;
  }
  {
    auto temp = (*key_code_value).GetIfInt();
    if (!temp.has_value()) {
      return false;
    }
    out->key_code = temp.value();
  }

  const base::Value* key_name_value = dict->FindKey("keyName");
  if (!key_name_value) {
    return false;
  }
  {
    auto* temp = (*key_name_value).GetIfString();
    if (!temp) {
      return false;
    }
    out->key_name = *temp;
  }

  const base::Value* modifiers_value = dict->FindKey("modifiers");
  if (modifiers_value) {
    {
      auto temp = (*modifiers_value).GetIfInt();
      if (!temp.has_value()) {
        out->modifiers.reset();
        return false;
      }
      out->modifiers = std::make_unique<int>(temp.value());
    }
  }

  return true;
}

// static
std::unique_ptr<VirtualKeyboardEvent> VirtualKeyboardEvent::FromValue(const base::Value& value) {
  auto out = std::make_unique<VirtualKeyboardEvent>();
  bool result = Populate(value, out.get());
  if (!result)
    return nullptr;
  return out;
}

std::unique_ptr<base::DictionaryValue> VirtualKeyboardEvent::ToValue() const {
  auto to_value_result =
      std::make_unique<base::DictionaryValue>();

  to_value_result->SetWithoutPathExpansion("type", std::make_unique<base::Value>(virtual_keyboard_private::ToString(this->type)));

  to_value_result->SetWithoutPathExpansion("charValue", std::make_unique<base::Value>(this->char_value));

  to_value_result->SetWithoutPathExpansion("keyCode", std::make_unique<base::Value>(this->key_code));

  to_value_result->SetWithoutPathExpansion("keyName", std::make_unique<base::Value>(this->key_name));

  if (this->modifiers.get()) {
    to_value_result->SetWithoutPathExpansion("modifiers", std::make_unique<base::Value>(*this->modifiers));

  }

  return to_value_result;
}


const char* ToString(KeyboardMode enum_param) {
  switch (enum_param) {
    case KEYBOARD_MODE_FULL_WIDTH:
      return "FULL_WIDTH";
    case KEYBOARD_MODE_FLOATING:
      return "FLOATING";
    case KEYBOARD_MODE_NONE:
      return "";
  }
  NOTREACHED();
  return "";
}

KeyboardMode ParseKeyboardMode(const std::string& enum_string) {
  if (enum_string == "FULL_WIDTH")
    return KEYBOARD_MODE_FULL_WIDTH;
  if (enum_string == "FLOATING")
    return KEYBOARD_MODE_FLOATING;
  return KEYBOARD_MODE_NONE;
}


const char* ToString(KeyboardState enum_param) {
  switch (enum_param) {
    case KEYBOARD_STATE_ENABLED:
      return "ENABLED";
    case KEYBOARD_STATE_DISABLED:
      return "DISABLED";
    case KEYBOARD_STATE_AUTO:
      return "AUTO";
    case KEYBOARD_STATE_NONE:
      return "";
  }
  NOTREACHED();
  return "";
}

KeyboardState ParseKeyboardState(const std::string& enum_string) {
  if (enum_string == "ENABLED")
    return KEYBOARD_STATE_ENABLED;
  if (enum_string == "DISABLED")
    return KEYBOARD_STATE_DISABLED;
  if (enum_string == "AUTO")
    return KEYBOARD_STATE_AUTO;
  return KEYBOARD_STATE_NONE;
}


Bounds::Bounds()
: left(0),
top(0),
width(0),
height(0) {}

Bounds::~Bounds() = default;
Bounds::Bounds(Bounds&& rhs) = default;
Bounds& Bounds::operator=(Bounds&& rhs) = default;
// static
bool Bounds::Populate(
    const base::Value& value, Bounds* out) {
  if (!value.is_dict()) {
    return false;
  }
  const auto* dict = static_cast<const base::DictionaryValue*>(&value);
  const base::Value* left_value = dict->FindKey("left");
  if (!left_value) {
    return false;
  }
  {
    auto temp = (*left_value).GetIfInt();
    if (!temp.has_value()) {
      return false;
    }
    out->left = temp.value();
  }

  const base::Value* top_value = dict->FindKey("top");
  if (!top_value) {
    return false;
  }
  {
    auto temp = (*top_value).GetIfInt();
    if (!temp.has_value()) {
      return false;
    }
    out->top = temp.value();
  }

  const base::Value* width_value = dict->FindKey("width");
  if (!width_value) {
    return false;
  }
  {
    auto temp = (*width_value).GetIfInt();
    if (!temp.has_value()) {
      return false;
    }
    out->width = temp.value();
  }

  const base::Value* height_value = dict->FindKey("height");
  if (!height_value) {
    return false;
  }
  {
    auto temp = (*height_value).GetIfInt();
    if (!temp.has_value()) {
      return false;
    }
    out->height = temp.value();
  }

  return true;
}

// static
std::unique_ptr<Bounds> Bounds::FromValue(const base::Value& value) {
  auto out = std::make_unique<Bounds>();
  bool result = Populate(value, out.get());
  if (!result)
    return nullptr;
  return out;
}

std::unique_ptr<base::DictionaryValue> Bounds::ToValue() const {
  auto to_value_result =
      std::make_unique<base::DictionaryValue>();

  to_value_result->SetWithoutPathExpansion("left", std::make_unique<base::Value>(this->left));

  to_value_result->SetWithoutPathExpansion("top", std::make_unique<base::Value>(this->top));

  to_value_result->SetWithoutPathExpansion("width", std::make_unique<base::Value>(this->width));

  to_value_result->SetWithoutPathExpansion("height", std::make_unique<base::Value>(this->height));


  return to_value_result;
}


KeyboardConfig::KeyboardConfig()
: hotrodmode(false),
a11ymode(false) {}

KeyboardConfig::~KeyboardConfig() = default;
KeyboardConfig::KeyboardConfig(KeyboardConfig&& rhs) = default;
KeyboardConfig& KeyboardConfig::operator=(KeyboardConfig&& rhs) = default;
// static
bool KeyboardConfig::Populate(
    const base::Value& value, KeyboardConfig* out) {
  if (!value.is_dict()) {
    return false;
  }
  const auto* dict = static_cast<const base::DictionaryValue*>(&value);
  const base::Value* layout_value = dict->FindKey("layout");
  if (!layout_value) {
    return false;
  }
  {
    auto* temp = (*layout_value).GetIfString();
    if (!temp) {
      return false;
    }
    out->layout = *temp;
  }

  const base::Value* hotrodmode_value = dict->FindKey("hotrodmode");
  if (!hotrodmode_value) {
    return false;
  }
  {
    auto temp = (*hotrodmode_value).GetIfBool();
    if (!temp.has_value()) {
      return false;
    }
    out->hotrodmode = temp.value();
  }

  const base::Value* a11ymode_value = dict->FindKey("a11ymode");
  if (!a11ymode_value) {
    return false;
  }
  {
    auto temp = (*a11ymode_value).GetIfBool();
    if (!temp.has_value()) {
      return false;
    }
    out->a11ymode = temp.value();
  }

  const base::Value* features_value = dict->FindKey("features");
  if (!features_value) {
    return false;
  }
  {
    if (!(*features_value).is_list()) {
      return false;
    }
    else {
      if (!json_schema_compiler::util::PopulateArrayFromList((*features_value).GetListDeprecated(), &out->features)) {
        return false;
      }
    }
  }

  return true;
}

// static
std::unique_ptr<KeyboardConfig> KeyboardConfig::FromValue(const base::Value& value) {
  auto out = std::make_unique<KeyboardConfig>();
  bool result = Populate(value, out.get());
  if (!result)
    return nullptr;
  return out;
}

std::unique_ptr<base::DictionaryValue> KeyboardConfig::ToValue() const {
  auto to_value_result =
      std::make_unique<base::DictionaryValue>();

  to_value_result->SetWithoutPathExpansion("layout", std::make_unique<base::Value>(this->layout));

  to_value_result->SetWithoutPathExpansion("hotrodmode", std::make_unique<base::Value>(this->hotrodmode));

  to_value_result->SetWithoutPathExpansion("a11ymode", std::make_unique<base::Value>(this->a11ymode));

  to_value_result->SetWithoutPathExpansion("features", json_schema_compiler::util::CreateValueFromArray(this->features));


  return to_value_result;
}


ContainerBehaviorOptions::ContainerBehaviorOptions()
: mode(KEYBOARD_MODE_NONE) {}

ContainerBehaviorOptions::~ContainerBehaviorOptions() = default;
ContainerBehaviorOptions::ContainerBehaviorOptions(ContainerBehaviorOptions&& rhs) = default;
ContainerBehaviorOptions& ContainerBehaviorOptions::operator=(ContainerBehaviorOptions&& rhs) = default;
// static
bool ContainerBehaviorOptions::Populate(
    const base::Value& value, ContainerBehaviorOptions* out) {
  if (!value.is_dict()) {
    return false;
  }
  const auto* dict = static_cast<const base::DictionaryValue*>(&value);
  const base::Value* mode_value = dict->FindKey("mode");
  if (!mode_value) {
    return false;
  }
  {
    const std::string* keyboard_mode_as_string = (*mode_value).GetIfString();
    if (!keyboard_mode_as_string) {
      return false;
    }
    out->mode = ParseKeyboardMode(*keyboard_mode_as_string);
    if (out->mode == KEYBOARD_MODE_NONE) {
      return false;
    }
  }

  const base::Value* bounds_value = dict->FindKey("bounds");
  if (!bounds_value) {
    return false;
  }
  {
    if (!(*bounds_value).is_dict()) {
      return false;
    }
    if (!Bounds::Populate((*bounds_value), &out->bounds)) {
      return false;
    }
  }

  return true;
}

// static
std::unique_ptr<ContainerBehaviorOptions> ContainerBehaviorOptions::FromValue(const base::Value& value) {
  auto out = std::make_unique<ContainerBehaviorOptions>();
  bool result = Populate(value, out.get());
  if (!result)
    return nullptr;
  return out;
}

std::unique_ptr<base::DictionaryValue> ContainerBehaviorOptions::ToValue() const {
  auto to_value_result =
      std::make_unique<base::DictionaryValue>();

  to_value_result->SetWithoutPathExpansion("mode", std::make_unique<base::Value>(virtual_keyboard_private::ToString(this->mode)));

  to_value_result->SetWithoutPathExpansion("bounds", (this->bounds).ToValue());


  return to_value_result;
}


const char* ToString(DisplayFormat enum_param) {
  switch (enum_param) {
    case DISPLAY_FORMAT_TEXT:
      return "text";
    case DISPLAY_FORMAT_PNG:
      return "png";
    case DISPLAY_FORMAT_HTML:
      return "html";
    case DISPLAY_FORMAT_FILE:
      return "file";
    case DISPLAY_FORMAT_NONE:
      return "";
  }
  NOTREACHED();
  return "";
}

DisplayFormat ParseDisplayFormat(const std::string& enum_string) {
  if (enum_string == "text")
    return DISPLAY_FORMAT_TEXT;
  if (enum_string == "png")
    return DISPLAY_FORMAT_PNG;
  if (enum_string == "html")
    return DISPLAY_FORMAT_HTML;
  if (enum_string == "file")
    return DISPLAY_FORMAT_FILE;
  return DISPLAY_FORMAT_NONE;
}


ClipboardItem::ClipboardItem()
: display_format(DISPLAY_FORMAT_NONE),
time_copied(0.0) {}

ClipboardItem::~ClipboardItem() = default;
ClipboardItem::ClipboardItem(ClipboardItem&& rhs) = default;
ClipboardItem& ClipboardItem::operator=(ClipboardItem&& rhs) = default;
// static
bool ClipboardItem::Populate(
    const base::Value& value, ClipboardItem* out) {
  if (!value.is_dict()) {
    return false;
  }
  const auto* dict = static_cast<const base::DictionaryValue*>(&value);
  const base::Value* id_value = dict->FindKey("id");
  if (!id_value) {
    return false;
  }
  {
    auto* temp = (*id_value).GetIfString();
    if (!temp) {
      return false;
    }
    out->id = *temp;
  }

  const base::Value* image_data_value = dict->FindKey("imageData");
  if (image_data_value) {
    {
      auto* temp = (*image_data_value).GetIfString();
      if (!temp) {
        out->image_data.reset();
        return false;
      }
      out->image_data = std::make_unique<std::string>(*temp);
    }
  }

  const base::Value* text_data_value = dict->FindKey("textData");
  if (text_data_value) {
    {
      auto* temp = (*text_data_value).GetIfString();
      if (!temp) {
        out->text_data.reset();
        return false;
      }
      out->text_data = std::make_unique<std::string>(*temp);
    }
  }

  const base::Value* display_format_value = dict->FindKey("displayFormat");
  if (!display_format_value) {
    return false;
  }
  {
    const std::string* display_format_as_string = (*display_format_value).GetIfString();
    if (!display_format_as_string) {
      return false;
    }
    out->display_format = ParseDisplayFormat(*display_format_as_string);
    if (out->display_format == DISPLAY_FORMAT_NONE) {
      return false;
    }
  }

  const base::Value* time_copied_value = dict->FindKey("timeCopied");
  if (!time_copied_value) {
    return false;
  }
  {
    auto temp = (*time_copied_value).GetIfDouble();
    if (!temp.has_value()) {
      return false;
    }
    out->time_copied = temp.value();
  }

  return true;
}

// static
std::unique_ptr<ClipboardItem> ClipboardItem::FromValue(const base::Value& value) {
  auto out = std::make_unique<ClipboardItem>();
  bool result = Populate(value, out.get());
  if (!result)
    return nullptr;
  return out;
}

std::unique_ptr<base::DictionaryValue> ClipboardItem::ToValue() const {
  auto to_value_result =
      std::make_unique<base::DictionaryValue>();

  to_value_result->SetWithoutPathExpansion("id", std::make_unique<base::Value>(this->id));

  if (this->image_data.get()) {
    to_value_result->SetWithoutPathExpansion("imageData", std::make_unique<base::Value>(*this->image_data));

  }
  if (this->text_data.get()) {
    to_value_result->SetWithoutPathExpansion("textData", std::make_unique<base::Value>(*this->text_data));

  }
  to_value_result->SetWithoutPathExpansion("displayFormat", std::make_unique<base::Value>(virtual_keyboard_private::ToString(this->display_format)));

  to_value_result->SetWithoutPathExpansion("timeCopied", std::make_unique<base::Value>(this->time_copied));


  return to_value_result;
}



//
// Functions
//

namespace InsertText {

Params::Params() = default;
Params::~Params() = default;

// static
std::unique_ptr<Params> Params::Create(const base::Value::ConstListView& args) {
  if (args.size() != 1) {
    return nullptr;
  }
  std::unique_ptr<Params> params(new Params());

  if (0 < args.size() &&
      !args[0].is_none()) {
    const base::Value& text_value = args[0];
    {
      auto* temp = text_value.GetIfString();
      if (!temp) {
        return std::unique_ptr<Params>();
      }
      params->text = *temp;
    }
  }
  else {
    return std::unique_ptr<Params>();
  }

  return params;
}


std::vector<base::Value> Results::Create() {
  std::vector<base::Value> create_results;

  return create_results;
}
}  // namespace InsertText

namespace SendKeyEvent {

Params::Params() = default;
Params::~Params() = default;

// static
std::unique_ptr<Params> Params::Create(const base::Value::ConstListView& args) {
  if (args.size() != 1) {
    return nullptr;
  }
  std::unique_ptr<Params> params(new Params());

  if (0 < args.size() &&
      !args[0].is_none()) {
    const base::Value& key_event_value = args[0];
    {
      if (!key_event_value.is_dict()) {
        return std::unique_ptr<Params>();
      }
      if (!VirtualKeyboardEvent::Populate(key_event_value, &params->key_event)) {
        return std::unique_ptr<Params>();
      }
    }
  }
  else {
    return std::unique_ptr<Params>();
  }

  return params;
}


std::vector<base::Value> Results::Create() {
  std::vector<base::Value> create_results;

  return create_results;
}
}  // namespace SendKeyEvent

namespace HideKeyboard {

std::vector<base::Value> Results::Create() {
  std::vector<base::Value> create_results;

  return create_results;
}
}  // namespace HideKeyboard

namespace SetHotrodKeyboard {

Params::Params() = default;
Params::~Params() = default;

// static
std::unique_ptr<Params> Params::Create(const base::Value::ConstListView& args) {
  if (args.size() != 1) {
    return nullptr;
  }
  std::unique_ptr<Params> params(new Params());

  if (0 < args.size() &&
      !args[0].is_none()) {
    const base::Value& enable_value = args[0];
    {
      auto temp = enable_value.GetIfBool();
      if (!temp.has_value()) {
        return std::unique_ptr<Params>();
      }
      params->enable = temp.value();
    }
  }
  else {
    return std::unique_ptr<Params>();
  }

  return params;
}


}  // namespace SetHotrodKeyboard

namespace LockKeyboard {

Params::Params() = default;
Params::~Params() = default;

// static
std::unique_ptr<Params> Params::Create(const base::Value::ConstListView& args) {
  if (args.size() != 1) {
    return nullptr;
  }
  std::unique_ptr<Params> params(new Params());

  if (0 < args.size() &&
      !args[0].is_none()) {
    const base::Value& lock_value = args[0];
    {
      auto temp = lock_value.GetIfBool();
      if (!temp.has_value()) {
        return std::unique_ptr<Params>();
      }
      params->lock = temp.value();
    }
  }
  else {
    return std::unique_ptr<Params>();
  }

  return params;
}


}  // namespace LockKeyboard

namespace KeyboardLoaded {

std::vector<base::Value> Results::Create() {
  std::vector<base::Value> create_results;

  return create_results;
}
}  // namespace KeyboardLoaded

namespace GetKeyboardConfig {

std::vector<base::Value> Results::Create(const KeyboardConfig& config) {
  std::vector<base::Value> create_results;
  create_results.reserve(1);
  create_results.push_back(base::Value::FromUniquePtrValue((config).ToValue()));

  return create_results;
}
}  // namespace GetKeyboardConfig

namespace OpenSettings {

}  // namespace OpenSettings

namespace OpenSuggestionSettings {

}  // namespace OpenSuggestionSettings

namespace SetContainerBehavior {

Params::Params() = default;
Params::~Params() = default;

// static
std::unique_ptr<Params> Params::Create(const base::Value::ConstListView& args) {
  if (args.size() != 1) {
    return nullptr;
  }
  std::unique_ptr<Params> params(new Params());

  if (0 < args.size() &&
      !args[0].is_none()) {
    const base::Value& options_value = args[0];
    {
      if (!options_value.is_dict()) {
        return std::unique_ptr<Params>();
      }
      if (!ContainerBehaviorOptions::Populate(options_value, &params->options)) {
        return std::unique_ptr<Params>();
      }
    }
  }
  else {
    return std::unique_ptr<Params>();
  }

  return params;
}


std::vector<base::Value> Results::Create(bool success) {
  std::vector<base::Value> create_results;
  create_results.reserve(1);
  create_results.push_back(base::Value::FromUniquePtrValue(std::make_unique<base::Value>(success)));

  return create_results;
}
}  // namespace SetContainerBehavior

namespace SetDraggableArea {

Params::Params() = default;
Params::~Params() = default;

// static
std::unique_ptr<Params> Params::Create(const base::Value::ConstListView& args) {
  if (args.size() != 1) {
    return nullptr;
  }
  std::unique_ptr<Params> params(new Params());

  if (0 < args.size() &&
      !args[0].is_none()) {
    const base::Value& bounds_value = args[0];
    {
      if (!bounds_value.is_dict()) {
        return std::unique_ptr<Params>();
      }
      if (!Bounds::Populate(bounds_value, &params->bounds)) {
        return std::unique_ptr<Params>();
      }
    }
  }
  else {
    return std::unique_ptr<Params>();
  }

  return params;
}


}  // namespace SetDraggableArea

namespace SetKeyboardState {

Params::Params() = default;
Params::~Params() = default;

// static
std::unique_ptr<Params> Params::Create(const base::Value::ConstListView& args) {
  if (args.size() != 1) {
    return nullptr;
  }
  std::unique_ptr<Params> params(new Params());

  if (0 < args.size() &&
      !args[0].is_none()) {
    const base::Value& state_value = args[0];
    {
      const std::string* keyboard_state_as_string = state_value.GetIfString();
      if (!keyboard_state_as_string) {
        return std::unique_ptr<Params>();
      }
      params->state = ParseKeyboardState(*keyboard_state_as_string);
      if (params->state == KEYBOARD_STATE_NONE) {
        return std::unique_ptr<Params>();
      }
    }
  }
  else {
    return std::unique_ptr<Params>();
  }

  return params;
}


}  // namespace SetKeyboardState

namespace SetOccludedBounds {

Params::Params() = default;
Params::~Params() = default;

// static
std::unique_ptr<Params> Params::Create(const base::Value::ConstListView& args) {
  if (args.size() != 1) {
    return nullptr;
  }
  std::unique_ptr<Params> params(new Params());

  if (0 < args.size() &&
      !args[0].is_none()) {
    const base::Value& bounds_list_value = args[0];
    {
      if (!bounds_list_value.is_list()) {
        return std::unique_ptr<Params>();
      }
      else {
        if (!json_schema_compiler::util::PopulateArrayFromList(bounds_list_value.GetListDeprecated(), &params->bounds_list)) {
          return std::unique_ptr<Params>();
        }
      }
    }
  }
  else {
    return std::unique_ptr<Params>();
  }

  return params;
}


}  // namespace SetOccludedBounds

namespace SetHitTestBounds {

Params::Params() = default;
Params::~Params() = default;

// static
std::unique_ptr<Params> Params::Create(const base::Value::ConstListView& args) {
  if (args.size() != 1) {
    return nullptr;
  }
  std::unique_ptr<Params> params(new Params());

  if (0 < args.size() &&
      !args[0].is_none()) {
    const base::Value& bounds_list_value = args[0];
    {
      if (!bounds_list_value.is_list()) {
        return std::unique_ptr<Params>();
      }
      else {
        if (!json_schema_compiler::util::PopulateArrayFromList(bounds_list_value.GetListDeprecated(), &params->bounds_list)) {
          return std::unique_ptr<Params>();
        }
      }
    }
  }
  else {
    return std::unique_ptr<Params>();
  }

  return params;
}


}  // namespace SetHitTestBounds

namespace SetAreaToRemainOnScreen {

Params::Params() = default;
Params::~Params() = default;

// static
std::unique_ptr<Params> Params::Create(const base::Value::ConstListView& args) {
  if (args.size() != 1) {
    return nullptr;
  }
  std::unique_ptr<Params> params(new Params());

  if (0 < args.size() &&
      !args[0].is_none()) {
    const base::Value& bounds_value = args[0];
    {
      if (!bounds_value.is_dict()) {
        return std::unique_ptr<Params>();
      }
      if (!Bounds::Populate(bounds_value, &params->bounds)) {
        return std::unique_ptr<Params>();
      }
    }
  }
  else {
    return std::unique_ptr<Params>();
  }

  return params;
}


}  // namespace SetAreaToRemainOnScreen

namespace SetWindowBoundsInScreen {

Params::Params() = default;
Params::~Params() = default;

// static
std::unique_ptr<Params> Params::Create(const base::Value::ConstListView& args) {
  if (args.size() != 1) {
    return nullptr;
  }
  std::unique_ptr<Params> params(new Params());

  if (0 < args.size() &&
      !args[0].is_none()) {
    const base::Value& bounds_value = args[0];
    {
      if (!bounds_value.is_dict()) {
        return std::unique_ptr<Params>();
      }
      if (!Bounds::Populate(bounds_value, &params->bounds)) {
        return std::unique_ptr<Params>();
      }
    }
  }
  else {
    return std::unique_ptr<Params>();
  }

  return params;
}


}  // namespace SetWindowBoundsInScreen

namespace GetClipboardHistory {

Params::Options::Options()
 {}

Params::Options::~Options() = default;
Params::Options::Options(Options&& rhs) = default;
Params::Options& Params::Options::operator=(Options&& rhs) = default;
// static
bool Params::Options::Populate(
    const base::Value& value, Options* out) {
  if (!value.is_dict()) {
    return false;
  }
  const auto* dict = static_cast<const base::DictionaryValue*>(&value);
  const base::Value* item_ids_value = dict->FindKey("itemIds");
  if (item_ids_value) {
    {
      if (!(*item_ids_value).is_list()) {
        return false;
      }
      else {
        if (!json_schema_compiler::util::PopulateOptionalArrayFromList((*item_ids_value).GetListDeprecated(), &out->item_ids)) {
          return false;
        }
      }
    }
  }

  return true;
}


Params::Params() = default;
Params::~Params() = default;

// static
std::unique_ptr<Params> Params::Create(const base::Value::ConstListView& args) {
  if (args.size() != 1) {
    return nullptr;
  }
  std::unique_ptr<Params> params(new Params());

  if (0 < args.size() &&
      !args[0].is_none()) {
    const base::Value& options_value = args[0];
    {
      if (!options_value.is_dict()) {
        return std::unique_ptr<Params>();
      }
      if (!Options::Populate(options_value, &params->options)) {
        return std::unique_ptr<Params>();
      }
    }
  }
  else {
    return std::unique_ptr<Params>();
  }

  return params;
}


std::vector<base::Value> Results::Create(const std::vector<ClipboardItem>& clipboard_history) {
  std::vector<base::Value> create_results;
  create_results.reserve(1);
  create_results.push_back(base::Value::FromUniquePtrValue(json_schema_compiler::util::CreateValueFromArray(clipboard_history)));

  return create_results;
}
}  // namespace GetClipboardHistory

namespace PasteClipboardItem {

Params::Params() = default;
Params::~Params() = default;

// static
std::unique_ptr<Params> Params::Create(const base::Value::ConstListView& args) {
  if (args.size() != 1) {
    return nullptr;
  }
  std::unique_ptr<Params> params(new Params());

  if (0 < args.size() &&
      !args[0].is_none()) {
    const base::Value& item_id_value = args[0];
    {
      auto* temp = item_id_value.GetIfString();
      if (!temp) {
        return std::unique_ptr<Params>();
      }
      params->item_id = *temp;
    }
  }
  else {
    return std::unique_ptr<Params>();
  }

  return params;
}


}  // namespace PasteClipboardItem

namespace DeleteClipboardItem {

Params::Params() = default;
Params::~Params() = default;

// static
std::unique_ptr<Params> Params::Create(const base::Value::ConstListView& args) {
  if (args.size() != 1) {
    return nullptr;
  }
  std::unique_ptr<Params> params(new Params());

  if (0 < args.size() &&
      !args[0].is_none()) {
    const base::Value& item_id_value = args[0];
    {
      auto* temp = item_id_value.GetIfString();
      if (!temp) {
        return std::unique_ptr<Params>();
      }
      params->item_id = *temp;
    }
  }
  else {
    return std::unique_ptr<Params>();
  }

  return params;
}


}  // namespace DeleteClipboardItem

//
// Events
//

namespace OnBoundsChanged {

const char kEventName[] = "virtualKeyboardPrivate.onBoundsChanged";

std::vector<base::Value> Create(const Bounds& bounds) {
  std::vector<base::Value> create_results;
  create_results.reserve(1);
  create_results.push_back(base::Value::FromUniquePtrValue((bounds).ToValue()));

  return create_results;
}

}  // namespace OnBoundsChanged

namespace OnKeyboardClosed {

const char kEventName[] = "virtualKeyboardPrivate.onKeyboardClosed";

std::vector<base::Value> Create() {
  std::vector<base::Value> create_results;

  return create_results;
}

}  // namespace OnKeyboardClosed

namespace OnKeyboardConfigChanged {

const char kEventName[] = "virtualKeyboardPrivate.onKeyboardConfigChanged";

std::vector<base::Value> Create(const KeyboardConfig& config) {
  std::vector<base::Value> create_results;
  create_results.reserve(1);
  create_results.push_back(base::Value::FromUniquePtrValue((config).ToValue()));

  return create_results;
}

}  // namespace OnKeyboardConfigChanged

namespace OnClipboardHistoryChanged {

const char kEventName[] = "virtualKeyboardPrivate.onClipboardHistoryChanged";

std::vector<base::Value> Create(const std::vector<std::string>& item_ids) {
  std::vector<base::Value> create_results;
  create_results.reserve(1);
  create_results.push_back(base::Value::FromUniquePtrValue(json_schema_compiler::util::CreateValueFromArray(item_ids)));

  return create_results;
}

}  // namespace OnClipboardHistoryChanged

namespace OnClipboardItemUpdated {

const char kEventName[] = "virtualKeyboardPrivate.onClipboardItemUpdated";

std::vector<base::Value> Create(const ClipboardItem& clipboard_history_item) {
  std::vector<base::Value> create_results;
  create_results.reserve(1);
  create_results.push_back(base::Value::FromUniquePtrValue((clipboard_history_item).ToValue()));

  return create_results;
}

}  // namespace OnClipboardItemUpdated

}  // namespace virtual_keyboard_private
}  // namespace api
}  // namespace extensions

